Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(99)

Unified Diff: trunk/src/remoting/host/desktop_session_proxy.h

Issue 151163002: Revert 248045 "Use webrtc::MouseCursorMonitor for cursor shapes" (Closed) Base URL: svn://svn.chromium.org/chrome/
Patch Set: Created 6 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « trunk/src/remoting/host/desktop_session_agent.cc ('k') | trunk/src/remoting/host/desktop_session_proxy.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: trunk/src/remoting/host/desktop_session_proxy.h
===================================================================
--- trunk/src/remoting/host/desktop_session_proxy.h (revision 248137)
+++ trunk/src/remoting/host/desktop_session_proxy.h (working copy)
@@ -31,12 +31,7 @@
class Message;
} // namespace IPC
-namespace webrtc {
-class MouseCursor;
-} // namespace webrtc
-
struct SerializedDesktopFrame;
-struct SerializedMouseCursor;
namespace remoting {
@@ -46,7 +41,6 @@
class DesktopSessionConnector;
struct DesktopSessionProxyTraits;
class IpcAudioCapturer;
-class IpcMouseCursorMonitor;
class IpcVideoFrameCapturer;
class ScreenControls;
@@ -83,7 +77,6 @@
scoped_ptr<InputInjector> CreateInputInjector();
scoped_ptr<ScreenControls> CreateScreenControls();
scoped_ptr<webrtc::ScreenCapturer> CreateVideoCapturer();
- scoped_ptr<webrtc::MouseCursorMonitor> CreateMouseCursorMonitor();
std::string GetCapabilities() const;
void SetCapabilities(const std::string& capabilities);
@@ -116,11 +109,6 @@
void SetVideoCapturer(
const base::WeakPtr<IpcVideoFrameCapturer> video_capturer);
- // Stores |mouse_cursor_monitor| to be used to post mouse cursor changes.
- // Called on the |video_capture_task_runner_| thread.
- void SetMouseCursorMonitor(
- const base::WeakPtr<IpcMouseCursorMonitor>& mouse_cursor_monitor);
-
// APIs used to implement the InputInjector interface.
void InjectClipboardEvent(const protocol::ClipboardEvent& event);
void InjectKeyEvent(const protocol::KeyEvent& event);
@@ -157,8 +145,8 @@
// Handles CaptureCompleted notification from the desktop session agent.
void OnCaptureCompleted(const SerializedDesktopFrame& serialized_frame);
- // Handles MouseCursor notification from the desktop session agent.
- void OnMouseCursor(const webrtc::MouseCursor& mouse_cursor);
+ // Handles CursorShapeChanged notification from the desktop session agent.
+ void OnCursorShapeChanged(const webrtc::MouseCursorShape& cursor_shape);
// Handles InjectClipboardEvent request from the desktop integration process.
void OnInjectClipboardEvent(const std::string& serialized_event);
@@ -167,9 +155,9 @@
// passing |frame|.
void PostCaptureCompleted(scoped_ptr<webrtc::DesktopFrame> frame);
- // Posts OnMouseCursor() to |mouse_cursor_monitor_| on the video thread,
- // passing |mouse_cursor|.
- void PostMouseCursor(scoped_ptr<webrtc::MouseCursor> mouse_cursor);
+ // Posts OnCursorShapeChanged() to |video_capturer_| on the video thread,
+ // passing |cursor_shape|.
+ void PostCursorShape(scoped_ptr<webrtc::MouseCursorShape> cursor_shape);
// Sends a message to the desktop session agent. The message is silently
// deleted if the channel is broken.
@@ -202,9 +190,6 @@
// Points to the video capturer receiving captured video frames.
base::WeakPtr<IpcVideoFrameCapturer> video_capturer_;
- // Points to the mouse cursor monitor receiving mouse cursor changes.
- base::WeakPtr<IpcMouseCursorMonitor> mouse_cursor_monitor_;
-
// IPC channel to the desktop session agent.
scoped_ptr<IPC::ChannelProxy> desktop_channel_;
« no previous file with comments | « trunk/src/remoting/host/desktop_session_agent.cc ('k') | trunk/src/remoting/host/desktop_session_proxy.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698